%bcond_without python3

Name:           ufw
Version:        0.36.2
Release:        %mkrel 1
Summary:        Uncomplicated Firewall
License:        GPL-3.0-only
Group:          System/Servers
URL:            https://launchpad.net/ufw
Source0:        https://launchpad.net/ufw/%{major_ver}/%{version}/+download/%{name}-%{version}.tar.xz
# System V init script file
Source2:        ufw.init

Patch2:         ufw-0.34~rc-default-enabled.patch
# Allow SSH connections by default
Patch3:         ufw-0.34~rc-default-allow-ssh.patch
# Define multicast protocols (mDNS, UPnP) as a normal protocol profile
# Use a managed rule instead of a "before" rule for default-allowing mDNS
# Do not allow UPnP by default at all, document in ufw.8 how it can be allowed
# Update the README file and the ufw.8 manpage according to the above changes
Patch4:         ufw-0.34~rc-multicast.patch
# Add protocol profiles for KDE Connect (#1257699) and Icecream (#1262009)
Patch5:         ufw-0.34~rc-additional-profiles.patch
# Change permissions of the *.rules files from 0640 to 0644
# Change permissions of the before.init and after.init hooks from 0640 to 0755
Patch7:         ufw-0.35-permissions.patch
# Don't prepend /usr/bin/env to sys.executable, which is always an absolute path
Patch8:         ufw-0.35-no-pointless-env.patch

BuildRequires:  bash-completion
BuildRequires:  iptables
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
Requires:       bash-completion
Recommends:     %{name}-lang
BuildArch:      noarch

%description
The Uncomplicated Firewall(ufw) is a front-end for netfilter, which
aims to make it easier for people unfamiliar with firewall concepts.
Ufw provides a framework for managing netfilter as well as
manipulating the firewall.

%prep
%setup -q
%patch2 -p1 -b .default-enabled
%patch3 -p1 -b .default-allow-ssh
%patch4 -p1 -b .multicast
rm -f profiles/*.multicast
%patch5 -p1 -b .additional-profiles
rm -f profiles/*.additional-profiles
%patch7 -p1 -b .permissions
%patch8 -p1 -b .no-pointless-env

%build
%if %{with python3}
%py3_build
%else
%py2_build
%endif

%install
%if %{with python3}
%py3_install
%else
%py2_install
%endif
install -D -p -m 755 %{SOURCE2} %{buildroot}%{_sysconfdir}/rc.d/init.d/%{name}
sed -i "1{s|/usr/bin/env||}" %{buildroot}%{_sbindir}/ufw
mkdir -p %{buildroot}/%{_bindir}
install -Dm0644 shell-completion/bash %{buildroot}%{_datadir}/bash-completion/completions/ufw.sh
ln -s %{_mandir}/man8/ufw.8.gz %{buildroot}%{_mandir}/man8/rcufw.8.gz
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
ln -s %{_sbindir}/ufw %{buildroot}/%{_bindir}/ufw

%find_lang %{name}

%post
/sbin/chkconfig --add %{name}
/sbin/chkconfig %{name} on
/sbin/service %{name} start > /dev/null 2>&1 || :

%preun
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig off
  /sbin/chkconfig --del %{name}
fi


%files -f %{name}.lang
/lib/ufw/ufw-init
/lib/ufw/ufw-init-functions
%{python3_sitelib}/ufw-%{version}-py%{python3_version}.egg-info
%{_sbindir}/ufw
%{_sbindir}/rcufw
%{_bindir}/ufw
%{_mandir}/man8/ufw-framework.8.bz2
%{_mandir}/man8/ufw.8.bz2

%dir %config %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/*.init
%config %{_sysconfdir}/%{name}/*.rules
%config %{_sysconfdir}/%{name}/*.conf

%config %{_sysconfdir}/%{name}/applications.d
%config %{_sysconfdir}/default/ufw
%{_datadir}/bash-completion/completions/ufw.sh
%if %{with systemd}
%{_unitdir}/%{name}.service
%else
%{_sysconfdir}/rc.d/init.d/%{name}
%endif
/lib/ufw
%{python3_sitelib}/ufw
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/iptables/*.rules
%exclude %{_datadir}/%{name}/messages



%changelog
* Thu Jun 01 2023 tex - 0.36.2-1pclos2023
- new version

* Tue Dec 13 2022 yodelu - 0.36.1-1pclos2022
- Update to version 0.36.1
